Features — Zds Member 1.0 documentation

# Features

## Sign up

The registration of a member is in two phases:

- The member creates their account and provides a username, a password and valid email address.
- A confirmation email is sent with a token that will activate the account.

Warning

- Commas are not allowed in the nickname, which also can not begin or end with spaces.
- The password must be at least 6 characters.

## Unsuscribe

## Promote member

## Add karma

## Reset Password